oc\_ocdm.graph.entities.bibliographic.resource\_embodiment module
-----------------------------------------------------------------

.. automodule:: oc_ocdm.graph.entities.bibliographic.resource_embodiment
   :members:
   :undoc-members:
   :show-inheritance:
